from flask import Flask, request
from .google_oauth import google_oauth
from ._defaults import Defaults

def auth(google_secrets_file_contents, auth_root, **kwArgs):
  auth_app = Flask('google-flask-oauth')
  auth_app.config.from_object(Defaults)
  auth_app.config['AUTH_ROOT'] = auth_root
  auth_app.config['AUTH_GOOGLE_SA_SECRET_CONTENTS'] = google_secrets_file_contents
  for key in kwArgs:
    auth_app.config['CUSTOM_{}'.format(key.upper())] = kwArgs[key]

  auth_app.register_blueprint(google_oauth)

  return auth_app

def aws_auth(**kwArgs):
  from ._aws_bootstrap import GOOGLE_CLIENT_SECRET, AUTH_ROOT
  return auth(GOOGLE_CLIENT_SECRET, AUTH_ROOT, **kwArgs)



from functools import wraps
import re
from flask import request, current_app, Response, g
from google.oauth2.credentials import Credentials
import google
import requests

def login_required(f):
  @wraps(f)
  def wrap(*args, **kwArgs):
    def failit():
      resp = Response()
      resp.headers['WWT-Authenticate'] = 'Bearer'
      resp.status_code = 401
      return resp

    if not request.headers['authorization']:
      return failit()
    matcher = re.match(r'(?i)bearer (.*)$', request.headers['authorization'])
    if not matcher:
      return failit()

    token = matcher.group(1)
    query_params = {'access_token': token}
    r = requests.post('https://oauth2.googleapis.com/tokeninfo', params=query_params)

    if r.status_code != requests.codes.ok:
      return failit()
    
    g.email = r.json()['email']

    return f(*args, **kwArgs)

  return wrap